import networkx as nx

from .T import SoCProfile, ChargingFunction
from ..T import Node, SoC
from ..graph_tools import charging_cofficient, consumption


def charging_function(
        G: nx.Graph,
        n: Node,
        capacity: SoC,
        initial_soc: SoC = None) -> ChargingFunction:
    """Create charging function of node."""
    return ChargingFunction(charging_cofficient(G, n), capacity, initial_soc)


def soc_profile(
        G: nx.Graph,
        capacity: SoC,
        u: Node,
        v: Node = None,
) -> SoCProfile:
    """
    Return SoC Profile of the path from u to v.

    If no v is provided, the path of u is definded as no cost path.

    """
    path_cost = 0 if v is None else consumption(G, u, v)
    return SoCProfile(path_cost, capacity)
