from math import inf

from evrouting.utils import PriorityQueue
from evrouting.T import SoC, Time

from .T import Label, SoCFunction, ChargingFunction


class LabelPriorityQueue(PriorityQueue):
    def insert(self, label: Label, cf: ChargingFunction):
        """Breaking ties with lowest soc at t_min."""
        soc_function = SoCFunction(
            label,
            cf
        )

        t_min: Time = soc_function.minimum

        # Might happen because of dummy charge stations
        if t_min == -inf:
            raise ValueError('Infeasible label.')

        soc_min: SoC = soc_function(t_min)

        super().insert(
            item=label,
            priority=t_min,
            count=soc_min
        )
